# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_menu import XMenu as XMenu_5f470841
if typing.TYPE_CHECKING:
    from .key_event import KeyEvent as KeyEvent_7a78097f
    from .rectangle import Rectangle as Rectangle_84b109e9
    from .x_window_peer import XWindowPeer as XWindowPeer_99760ab0
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc

class XPopupMenu(XMenu_5f470841):
    """
    controls a pop-up menu.

    See Also:
        `API XPopupMenu <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XPopupMenu.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XPopupMenu'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XPopupMenu'

    @abstractmethod
    def checkItem(self, nItemId: int, bCheck: bool) -> None:
        """
        sets the state of the item to be checked or unchecked.
        """
        ...
    @abstractmethod
    def endExecute(self) -> None:
        """
        ends the execution of the PopupMenu.
        
        com.sun.star.awt.XPopupMenu.execute() will then return 0.
        """
        ...
    @abstractmethod
    def execute(self, Parent: XWindowPeer_99760ab0, Position: Rectangle_84b109e9, Direction: int) -> int:
        """
        executes the popup menu and returns the selected item or 0, if cancelled.
        """
        ...
    @abstractmethod
    def getAcceleratorKeyEvent(self, nItemId: int) -> KeyEvent_7a78097f:
        """
        retrieves the KeyEvent for the menu item.
        
        The KeyEvent is only used as a container to transport the shortcut information, so that in this case com.sun.star.lang.EventObject.Source is NULL.
        """
        ...
    @abstractmethod
    def getDefaultItem(self) -> int:
        """
        returns the menu default item.
        """
        ...
    @abstractmethod
    def getItemImage(self, nItemId: int) -> XGraphic_a4da0afc:
        """
        retrieves the image for the menu item.
        """
        ...
    @abstractmethod
    def insertSeparator(self, nItemPos: int) -> None:
        """
        inserts a separator at the specified position.
        """
        ...
    @abstractmethod
    def isInExecute(self) -> bool:
        """
        queries if the PopupMenu is being.
        
        Returns TRUE only if the PopupMenu is being executed as a result of invoking XPopupMenu.execute(); that is, for a PopupMenu activated by a MenuBar item, this methods returns FALSE.
        """
        ...
    @abstractmethod
    def isItemChecked(self, nItemId: int) -> bool:
        """
        returns whether the item is checked or unchecked.
        """
        ...
    @abstractmethod
    def setAcceleratorKeyEvent(self, nItemId: int, aKeyEvent: KeyEvent_7a78097f) -> None:
        """
        sets the KeyEvent for the menu item.
        
        The KeyEvent is only used as a container to transport the shortcut information, this methods only draws the text corresponding to this keyboard shortcut. The client code is responsible for listening to keyboard events (typically done via XUserInputInterception), and dispatch the respective command.
        """
        ...
    @abstractmethod
    def setDefaultItem(self, nItemId: int) -> None:
        """
        sets the menu default item.
        """
        ...
    @abstractmethod
    def setItemImage(self, nItemId: int, xGraphic: XGraphic_a4da0afc, bScale: bool) -> None:
        """
        sets the image for the menu item.
        """
        ...

__all__ = ['XPopupMenu']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..awt.x_window import XWindow as XWindow_713b0924
    from .x_controller import XController as XController_b00e0b8f
    from .x_frame_action_listener import XFrameActionListener as XFrameActionListener_26250efa
    from .x_frames_supplier import XFramesSupplier as XFramesSupplier_e12a0d1d

class XFrame(XComponent_98dc0ab5):
    """
    a frame object can be considered to be an \"anchor\" object where a component can be attached to.
    
    A frame can be (it's not a must!) a part of a frame tree. If not this frame won't be accessible by using the API. This mode make sense for previews. The root node of the tree can be a Desktop implementation.

    See Also:
        `API XFrame <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XFrame'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XFrame'

    @abstractmethod
    def activate(self) -> None:
        """
        activates this frame and thus the component within.
        
        At first the frame sets itself as the active frame of its creator by calling XFramesSupplier.setActiveFrame(), then it broadcasts a FrameActionEvent with FrameAction.FRAME_ACTIVATED. The component within this frame may listen to this event to grab the focus on activation; for simple components this can be done by the FrameLoader.
        
        Finally, most frames may grab the focus to one of its windows or forward the activation to a sub-frame.
        """
        ...
    @abstractmethod
    def addFrameActionListener(self, xListener: XFrameActionListener_26250efa) -> None:
        """
        registers an event listener, which will be called when certain things happen to the components within this frame or within sub-frames of this frame.
        
        E.g., it is possible to determine instantiation/destruction and activation/deactivation of components.
        """
        ...
    @abstractmethod
    def contextChanged(self) -> None:
        """
        notifies the frame that the context of the controller within this frame changed (i.e.
        
        the selection).
        
        According to a call to this interface, the frame calls XFrameActionListener.frameAction() with FrameAction.CONTEXT_CHANGED to all listeners which are registered using XFrame.addFrameActionListener(). For external controllers this event can be used to requery dispatches.
        """
        ...
    @abstractmethod
    def deactivate(self) -> None:
        """
        is called by the creator frame when another sub-frame gets activated.
        
        At first the frame deactivates its active sub-frame, if any. Then broadcasts a FrameActionEvent with FrameAction.FRAME_DEACTIVATING.
        """
        ...
    @abstractmethod
    def findFrame(self, aTargetFrameName: str, nSearchFlags: int) -> XFrame:
        """
        searches for a frame with the specified name.
        
        Frames may contain other frames (e.g., a frameset) and may be contained in other frames. This hierarchy is searched with this method. First some special names are taken into account, i.e. \"\", \"_self\", \"_top\", \"_blank\" etc. SearchFlags is ignored when comparing these names with TargetFrameName; further steps are controlled by SearchFlags. If allowed, the name of the frame itself is compared with the desired one, and then ( again if allowed ) the method is called for all children of the frame. Finally may be called for the siblings and then for parent frame (if allowed).
        
        List of special target names:
        
        If no frame with the given name is found, a new top frame is created; if this is allowed by a special flag FrameSearchFlag.CREATE. The new frame also gets the desired name.
        """
        ...
    @abstractmethod
    def getComponentWindow(self) -> XWindow_713b0924:
        """
        provides access to the component window
        
        Note: Don't dispose this window - the frame is the owner of it.
        """
        ...
    @abstractmethod
    def getContainerWindow(self) -> XWindow_713b0924:
        """
        provides access to the container window of the frame.
        
        Normally this is used as the parent window of the component window.
        """
        ...
    @abstractmethod
    def getController(self) -> XController_b00e0b8f:
        """
        provides access to the controller
        
        Note: Don't dispose it - the frame is the owner of it. Use XController.getFrame() to dispose the frame after you the controller agreed with a XController.suspend() call.
        """
        ...
    @abstractmethod
    def getCreator(self) -> XFramesSupplier_e12a0d1d:
        """
        provides access to the creator (parent) of this frame
        """
        ...
    @abstractmethod
    def getName(self) -> str:
        """
        access to the name property of this frame
        """
        ...
    @abstractmethod
    def initialize(self, xWindow: XWindow_713b0924) -> None:
        """
        is called to initialize the frame within a window - the container window.
        
        This window will be used as parent for the component window and to support some UI relevant features of the frame service. Note: Re-parenting mustn't supported by a real frame implementation! It's designed for initializing - not for setting.
        
        This frame will take over ownership of the window referred from xWindow. Thus, the previous owner is not allowed to dispose this window anymore.
        """
        ...
    @abstractmethod
    def isActive(self) -> bool:
        """
        determines if the frame is active.
        """
        ...
    @abstractmethod
    def isTop(self) -> bool:
        """
        determines if the frame is a top frame.
        
        In general a top frame is the frame which is a direct child of a task frame or which does not have a parent. Possible frame searches must stop the search at such a frame unless the flag FrameSearchFlag.TASKS is set.
        """
        ...
    @abstractmethod
    def removeFrameActionListener(self, xListener: XFrameActionListener_26250efa) -> None:
        """
        unregisters an event listener
        """
        ...
    @abstractmethod
    def setComponent(self, xComponentWindow: XWindow_713b0924, xController: XController_b00e0b8f) -> bool:
        """
        sets a new component into the frame or release an existing one from a frame.
        
        A valid component window should be a child of the frame container window.
        
        Simple components may implement a com.sun.star.awt.XWindow only. In this case no controller must be given here.
        """
        ...
    @abstractmethod
    def setCreator(self, Creator: XFramesSupplier_e12a0d1d) -> None:
        """
        sets the frame container that created this frame.
        
        Only the creator is allowed to call this method. But creator doesn't mean the implementation which creates this instance ... it means the parent frame of the frame hierarchy. Because; normally a frame should be created by using the API and is necessary for searches inside the tree (e.g. XFrame.findFrame())
        """
        ...
    @abstractmethod
    def setName(self, aName: str) -> None:
        """
        sets the name of the frame.
        
        Normally the name of the frame is set initially (e.g. by the creator). The name of a frame will be used for identifying it if a frame search was started. These searches can be forced by:
        
        Note: Special targets like \"_blank\", \"_self\" etc. are not allowed. That's why frame names shouldn't start with a sign \"_\".
        """
        ...

__all__ = ['XFrame']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbcx
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_data_descriptor_factory import XDataDescriptorFactory as XDataDescriptorFactory_46170fe5

class Column(XPropertySet_bc180bfa, XDataDescriptorFactory_46170fe5):
    """
    Service Class

    describes the common properties of a database column.

    See Also:
        `API Column <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbcx_1_1Column.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbcx'
    __ooo_full_ns__: str = 'com.sun.star.sdbcx.Column'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DefaultValue(self) -> str:
        """
        keeps a default value for a column, is provided as string.
        """
        ...

    @abstractproperty
    def Description(self) -> str:
        """
        keeps a description of the object.
        """
        ...

    @abstractproperty
    def IsAutoIncrement(self) -> bool:
        """
        indicates whether the column is automatically numbered, thus read-only.
        """
        ...

    @abstractproperty
    def IsCurrency(self) -> bool:
        """
        indicates whether the column is a cash value.
        """
        ...

    @abstractproperty
    def IsNullable(self) -> int:
        """
        indicates the nullability of values in the designated column.
        """
        ...

    @abstractproperty
    def IsRowVersion(self) -> bool:
        """
        indicates that the column contains some kind of time or date stamp used to track updates.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        is the name of the column.
        """
        ...

    @abstractproperty
    def Precision(self) -> int:
        """
        gets a column's number of decimal digits.
        """
        ...

    @abstractproperty
    def Scale(self) -> int:
        """
        gets a column's number of digits to right of the decimal point.
        """
        ...

    @abstractproperty
    def Type(self) -> int:
        """
        is the com.sun.star.sdbc.DataType of the column.
        """
        ...

    @abstractproperty
    def TypeName(self) -> str:
        """
        is the type name used by the database.
        
        If the column type is a user-defined type, then a fully-qualified type name is returned.  Note:  May be empty.
        """
        ...


__all__ = ['Column']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class FadeEffect(Enum):
    """
    Enum Class


    See Also:
        `API FadeEffect <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3d>`_
    """
    __ooo_ns__: str = "com.sun.star.presentation"
    __ooo_full_ns__: str = "com.sun.star.presentation.FadeEffect"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.presentation.FadeEffect"

    CLOCKWISE = "CLOCKWISE"
    """
    use the animation effect \"Clockwise\".
    
    use the fade effect \"Clockwise\".
    """
    CLOSE_HORIZONTAL = "CLOSE_HORIZONTAL"
    """
    use the animation effect \"Close Horizontal\".
    
    use the fade effect \"Close Horizontal\".
    """
    CLOSE_VERTICAL = "CLOSE_VERTICAL"
    """
    use the animation effect \"Close Vertical\".
    
    use the fade effect \"Close Vertical\".
    """
    COUNTERCLOCKWISE = "COUNTERCLOCKWISE"
    """
    use the animation effect \"Counter Clockwise\".
    
    use the fade effect \"Counter Clockwise\".
    """
    DISSOLVE = "DISSOLVE"
    """
    use the animation effect \"Spiral Inward Left\".
    
    use the fade effect \"Dissolve\".
    """
    FADE_FROM_BOTTOM = "FADE_FROM_BOTTOM"
    """
    use the animation effect \"Fade from Bottom\".
    
    use the fade effect \"Fade from Bottom\".
    """
    FADE_FROM_CENTER = "FADE_FROM_CENTER"
    """
    use the animation effect \"Fade from Center\".
    
    use the fade effect \"Fade from Center\".
    """
    FADE_FROM_LEFT = "FADE_FROM_LEFT"
    """
    use the animation effect \"Fade from Left\".
    
    use the fade effect \"Fade from Left\".
    """
    FADE_FROM_LOWERLEFT = "FADE_FROM_LOWERLEFT"
    """
    use the animation effect \"Fade from Lower Left\".
    
    use the fade effect \"Fade from Lower Left\".
    """
    FADE_FROM_LOWERRIGHT = "FADE_FROM_LOWERRIGHT"
    """
    use the animation effect \"Fade from Lower Right\".
    
    use the fade effect \"Fade from Lower Right\".
    """
    FADE_FROM_RIGHT = "FADE_FROM_RIGHT"
    """
    use the animation effect \"Fade from Right\".
    
    use the fade effect \"Fade from Right\".
    """
    FADE_FROM_TOP = "FADE_FROM_TOP"
    """
    use the animation effect \"Fade from Top\".
    
    use the fade effect \"Fade from Top\".
    """
    FADE_FROM_UPPERLEFT = "FADE_FROM_UPPERLEFT"
    """
    use the animation effect \"Fade from Upper Left\".
    
    use the fade effect \"Fade from Upper Left\".
    """
    FADE_FROM_UPPERRIGHT = "FADE_FROM_UPPERRIGHT"
    """
    use the animation effect \"Fade from Upper Right\".
    
    use the fade effect \"Fade from Upper Right\".
    """
    FADE_TO_CENTER = "FADE_TO_CENTER"
    """
    use the animation effect \"Fade to Center\".
    
    use the fade effect \"Fade to Center\".
    """
    HORIZONTAL_CHECKERBOARD = "HORIZONTAL_CHECKERBOARD"
    """
    use the animation effect \"Horizontal Checkerboard\".
    
    use the fade effect \"Horizontal Checkerboard\".
    """
    HORIZONTAL_LINES = "HORIZONTAL_LINES"
    """
    use the animation effect \"Horizontal Lines\".
    
    use the fade effect \"Horizontal Lines\".
    """
    HORIZONTAL_STRIPES = "HORIZONTAL_STRIPES"
    """
    use the animation effect \"Horizontal Stripes\".
    
    use the fade effect \"Horizontal Stripes\".
    """
    MOVE_FROM_BOTTOM = "MOVE_FROM_BOTTOM"
    """
    use the animation effect \"Move from Bottom\".
    
    use the fade effect \"Move from Bottom\".
    """
    MOVE_FROM_LEFT = "MOVE_FROM_LEFT"
    """
    use the animation effect \"Move from Left\".
    
    use the fade effect \"Move from Left\".
    """
    MOVE_FROM_LOWERLEFT = "MOVE_FROM_LOWERLEFT"
    """
    use the animation effect \"Move from Lower Left\".
    
    use the fade effect \"Move from Lower Left\".
    """
    MOVE_FROM_LOWERRIGHT = "MOVE_FROM_LOWERRIGHT"
    """
    use the animation effect \"Move from Lower Right\".
    
    use the fade effect \"Move from Lower Right\".
    """
    MOVE_FROM_RIGHT = "MOVE_FROM_RIGHT"
    """
    use the animation effect \"Move from Right\".
    
    use the fade effect \"Move from Right\".
    """
    MOVE_FROM_TOP = "MOVE_FROM_TOP"
    """
    use the animation effect \"Move from Top\".
    
    use the fade effect \"Move from Top\".
    """
    MOVE_FROM_UPPERLEFT = "MOVE_FROM_UPPERLEFT"
    """
    use the animation effect \"Move from Upper Left\".
    
    use the fade effect \"Move from Upper Left\".
    """
    MOVE_FROM_UPPERRIGHT = "MOVE_FROM_UPPERRIGHT"
    """
    use the animation effect \"Move from Upper Right\".
    
    use the fade effect \"Move from Upper Right\".
    """
    NONE = "NONE"
    """
    use no animation effects.
    
    use no fade effects.
    
    No action is performed on click.
    """
    OPEN_HORIZONTAL = "OPEN_HORIZONTAL"
    """
    use the animation effect \"Open Horizontal\".
    
    use the fade effect \"Open Horizontal\".
    """
    OPEN_VERTICAL = "OPEN_VERTICAL"
    """
    use the animation effect \"Open Vertical\".
    
    use the fade effect \"Open Vertical\".
    """
    RANDOM = "RANDOM"
    """
    use the animation effect \"Random\".
    
    use the fade effect \"Random\".
    """
    ROLL_FROM_BOTTOM = "ROLL_FROM_BOTTOM"
    """
    use the fade effect \"Roll from Bottom\".
    """
    ROLL_FROM_LEFT = "ROLL_FROM_LEFT"
    """
    use the fade effect \"Roll from Left\".
    """
    ROLL_FROM_RIGHT = "ROLL_FROM_RIGHT"
    """
    use the fade effect \"Roll from Right\".
    """
    ROLL_FROM_TOP = "ROLL_FROM_TOP"
    """
    use the fade effect \"Roll from Top\".
    """
    SPIRALIN_LEFT = "SPIRALIN_LEFT"
    """
    use the animation effect \"Spiral Inward Left\".
    
    use the fade effect \"Spiral Inward Left\".
    """
    SPIRALIN_RIGHT = "SPIRALIN_RIGHT"
    """
    use the animation effect \"Spiral Inward Right\".
    
    use the fade effect \"Spiral Inward Right\".
    """
    SPIRALOUT_LEFT = "SPIRALOUT_LEFT"
    """
    use the animation effect \"Spiral Outward Left\".
    
    use the fade effect \"Spiral Outward Left\".
    """
    SPIRALOUT_RIGHT = "SPIRALOUT_RIGHT"
    """
    use the animation effect \"Spiral Outward Right\".
    
    use the fade effect \"Spiral Outward Right\".
    """
    STRETCH_FROM_BOTTOM = "STRETCH_FROM_BOTTOM"
    """
    use the animation effect \"Stretch From Bottom\".
    
    use the fade effect \"Stretch from Bottom\".
    """
    STRETCH_FROM_LEFT = "STRETCH_FROM_LEFT"
    """
    use the animation effect \"Stretch From Left\".
    
    use the fade effect \"Stretch from Left\".
    """
    STRETCH_FROM_RIGHT = "STRETCH_FROM_RIGHT"
    """
    use the animation effect \"Stretch From Right\".
    
    use the fade effect \"Stretch from Right\".
    """
    STRETCH_FROM_TOP = "STRETCH_FROM_TOP"
    """
    use the animation effect \"Stretch From Top\".
    
    use the fade effect \"Stretch from Top\".
    """
    UNCOVER_TO_BOTTOM = "UNCOVER_TO_BOTTOM"
    """
    use the fade effect \"Uncover to Bottom\".
    """
    UNCOVER_TO_LEFT = "UNCOVER_TO_LEFT"
    """
    use the fade effect \"Uncover to Left\".
    """
    UNCOVER_TO_LOWERLEFT = "UNCOVER_TO_LOWERLEFT"
    """
    use the fade effect \"Uncover to Lower Left\".
    """
    UNCOVER_TO_LOWERRIGHT = "UNCOVER_TO_LOWERRIGHT"
    """
    use the fade effect \"Uncover to Lower Right\".
    """
    UNCOVER_TO_RIGHT = "UNCOVER_TO_RIGHT"
    """
    use the fade effect \"Uncover to Right\".
    """
    UNCOVER_TO_TOP = "UNCOVER_TO_TOP"
    """
    use the fade effect \"Uncover to Top\".
    """
    UNCOVER_TO_UPPERLEFT = "UNCOVER_TO_UPPERLEFT"
    """
    use the fade effect \"Uncover to Upper Left\".
    """
    UNCOVER_TO_UPPERRIGHT = "UNCOVER_TO_UPPERRIGHT"
    """
    use the fade effect \"Uncover to Upper Right\".
    """
    VERTICAL_CHECKERBOARD = "VERTICAL_CHECKERBOARD"
    """
    use the animation effect \"Vertical Checkerboard\".
    
    use the fade effect \"Vertical Checkerboard\".
    """
    VERTICAL_LINES = "VERTICAL_LINES"
    """
    use the animation effect \"Vertical Lines\".
    
    use the fade effect \"Vertical Lines\".
    """
    VERTICAL_STRIPES = "VERTICAL_STRIPES"
    """
    use the animation effect \"Vertical Stripes\".
    
    use the fade effect \"Vertical Stripes\".
    """
    WAVYLINE_FROM_BOTTOM = "WAVYLINE_FROM_BOTTOM"
    """
    use the animation effect \"Wavy Line from Button\".
    
    use the fade effect \"Wavy Line from Bottom\".
    """
    WAVYLINE_FROM_LEFT = "WAVYLINE_FROM_LEFT"
    """
    use the animation effect \"Wavy Line from Left\".
    
    use the fade effect \"Wavy Line from Left\".
    """
    WAVYLINE_FROM_RIGHT = "WAVYLINE_FROM_RIGHT"
    """
    use the animation effect \"Wavy Line from Right\".
    
    use the fade effect \"Wavy Line from Right\".
    """
    WAVYLINE_FROM_TOP = "WAVYLINE_FROM_TOP"
    """
    use the animation effect \"Wavy Line from Top\".
    
    use the fade effect \"Wavy Line from Top\".
    """

__all__ = ["FadeEffect"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc


class KeyRule(object):
    """
    Const Class

    determines the rules for foreign key constraints.

    See Also:
        `API KeyRule <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdbc_1_1KeyRule.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.KeyRule'
    __ooo_type_name__: str = 'const'

    CASCADE = 0
    """
    a possible value for the column's UPDATE_RULE and DELETE_RULE in the com.sun.star.sdbc.XResultSet objects returned by the methods com.sun.star.sdbc.XDatabaseMetaData.getImportedKeys(), com.sun.star.sdbc.XDatabaseMetaData.getExportedKeys(), and com.sun.star.sdbc.XDatabaseMetaData.getCrossReference().
    
    For the column UPDATE_RULE , it indicates that when the primary key is updated, the foreign key (imported key) is changed to agree with it.
    
    For the column DELETE_RULE , it indicates that when the primary key is deleted, rows that imported that key are deleted.
    """
    RESTRICT = 1
    """
    a possible value for the column's UPDATE_RULE and DELETE_RULE in the com.sun.star.sdbc.XResultSet objects returned by the methods com.sun.star.sdbc.XDatabaseMetaData.getImportedKeys(), com.sun.star.sdbc.XDatabaseMetaData.getExportedKeys(), and com.sun.star.sdbc.XDatabaseMetaData.getCrossReference().
    
    For the column UPDATE_RULE , it indicates that a primary key may not be updated if it has been imported by another table as a foreign key.
    
    For the column DELETE_RULE , it indicates that a primary key may not be deleted if it has been imported by another table as a foreign key.
    """
    SET_NULL = 2
    """
    a possible value for the column's UPDATE_RULE and DELETE_RULE in the com.sun.star.sdbc.XResultSet objects returned by the methods com.sun.star.sdbc.XDatabaseMetaData.getImportedKeys(), com.sun.star.sdbc.XDatabaseMetaData.getExportedKeys(), and com.sun.star.sdbc.XDatabaseMetaData.getCrossReference().
    
    For the columns UPDATE_RULE and DELETE_RULE , it indicates that when the primary key is updated or deleted, the foreign key (imported key) is changed to NULL.
    """
    NO_ACTION = 3
    """
    a possible value for the column's UPDATE_RULE and DELETE_RULE in the com.sun.star.sdbc.XResultSet objects returned by the methods com.sun.star.sdbc.XDatabaseMetaData.getImportedKeys(), com.sun.star.sdbc.XDatabaseMetaData.getExportedKeys(), and com.sun.star.sdbc.XDatabaseMetaData.getCrossReference().
    
    For the columns UPDATE_RULE and DELETE_RULE , it indicates that if the primary key has been imported, it cannot be updated or deleted.
    """
    SET_DEFAULT = 4
    """
    a possible value for the column's UPDATE_RULE and DELETE_RULE in the com.sun.star.sdbc.XResultSet objects returned by the methods com.sun.star.sdbc.XDatabaseMetaData.getImportedKeys(), com.sun.star.sdbc.XDatabaseMetaData.getExportedKeys(), and com.sun.star.sdbc.XDatabaseMetaData.getCrossReference().
    
    For the columns UPDATE_RULE and DELETE_RULE , it indicates that if the primary key is updated or deleted, the foreign key (imported key) is set to the default value.
    """

__all__ = ['KeyRule']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.auth
from __future__ import annotations
import uno
from abc import abstractmethod
from .xsso_context import XSSOContext as XSSOContext_a2840aec

class XSSOInitiatorContext(XSSOContext_a2840aec):
    """
    represents an initiator side security context.
    
    This context may be used to initialize authentication tokens to send to an acceptor and to authenticate any token sent back in response.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XSSOInitiatorContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1auth_1_1XSSOInitiatorContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.auth'
    __ooo_full_ns__: str = 'com.sun.star.auth.XSSOInitiatorContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.auth.XSSOInitiatorContext'

    @abstractmethod
    def init(self, Token: uno.ByteSequence) -> uno.ByteSequence:
        """
        initializes an SSO Token to send to the acceptor side and authenticates an SSO Token returned by the acceptor if the context supports mutual authentication.
        
        init should be called only once for contexts which don't support mutual authentication and at most twice for contexts which do support mutual authentication. Additional calls produce undefined results.

        Raises:
            InvalidArgumentException: ``InvalidArgumentException``
            InvalidCredentialException: ``InvalidCredentialException``
            InvalidContextException: ``InvalidContextException``
            AuthenticationFailedException: ``AuthenticationFailedException``
        """
        ...

__all__ = ['XSSOInitiatorContext']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class X3DDisplay(XInterface_8f010a43):
    """
    gives access to 3D elements of a three-dimensional chart.

    See Also:
        `API X3DDisplay <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart_1_1X3DDisplay.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.X3DDisplay'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart.X3DDisplay'

    @abstractmethod
    def getFloor(self) -> XPropertySet_bc180bfa:
        """
        This is only valid for three-dimensional diagrams.
        """
        ...
    @abstractmethod
    def getWall(self) -> XPropertySet_bc180bfa:
        """
        This specifies the properties of the two side walls of the chart scene.
        
        Note that this property is also valid for two-dimensional diagrams. There the properties returned here affect the background rectangle of the diagram.
        """
        ...

__all__ = ['X3DDisplay']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.loader
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..registry.x_registry_key import XRegistryKey as XRegistryKey_e61a0d5b

class XImplementationLoader(XInterface_8f010a43):
    """
    handles activation (loading) of a UNO component.

    See Also:
        `API XImplementationLoader <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1loader_1_1XImplementationLoader.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.loader'
    __ooo_full_ns__: str = 'com.sun.star.loader.XImplementationLoader'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.loader.XImplementationLoader'

    @abstractmethod
    def activate(self, implementationName: str, implementationLoaderUrl: str, locationUrl: str, xKey: XRegistryKey_e61a0d5b) -> XInterface_8f010a43:
        """
        activates a concrete implementation within a component.
        
        Special loaders may define their own protocol (for instance an executable loader may need more than only one file url).

        Raises:
            com.sun.star.loader.CannotActivateFactoryException: ``CannotActivateFactoryException``
        """
        ...
    @abstractmethod
    def writeRegistryInfo(self, xKey: XRegistryKey_e61a0d5b, implementationLoaderUrl: str, locationUrl: str) -> bool:
        """
        writes a list of all implementations hosted by this component into a registry key.
        
        This method is called during registering a component.
        
        Special loaders may define their own protocol (for instance an executable loader may need more than only one file url).

        Raises:
            com.sun.star.registry.CannotRegisterImplementationException: ``CannotRegisterImplementationException``
        """
        ...

__all__ = ['XImplementationLoader']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.input
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_attributes import XAttributes as XAttributes_e31a0d36
    from .x_element import XElement as XElement_bc5b0bd9
    from .x_namespace_mapping import XNamespaceMapping as XNamespaceMapping_38700f68
    from ..sax.x_locator import XLocator as XLocator_a3fb0aff

class XRoot(XInterface_8f010a43):
    """
    Root interface being passed to SaxDocumentHandler service upon instantiation.

    See Also:
        `API XRoot <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1input_1_1XRoot.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.input'
    __ooo_full_ns__: str = 'com.sun.star.xml.input.XRoot'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.input.XRoot'

    @abstractmethod
    def endDocument(self) -> None:
        """
        Receives notification of the end of a document.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def processingInstruction(self, target: str, data: str) -> None:
        """
        Receives notification of a processing instruction.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def setDocumentLocator(self, locator: XLocator_a3fb0aff) -> None:
        """
        Receives an object for locating the origin of SAX document events.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def startDocument(self, xMapping: XNamespaceMapping_38700f68) -> None:
        """
        Receives notification of the beginning of a document.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def startRootElement(self, uid: int, localName: str, xAttributes: XAttributes_e31a0d36) -> XElement_bc5b0bd9:
        """
        Called upon root element.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...

__all__ = ['XRoot']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame
# Libre Office Version: 7.4
from .x_desktop2 import XDesktop2 as XDesktop2_98eb0a77


class theDesktop(XDesktop2_98eb0a77):
    """
    Singleton Class

    is the environment for components which can instantiate within frames
    
    A desktop environment contains tasks with one or more frames in which components can be loaded. The term \"task\" or naming a frame as a \"task frame\" is not in any way related to any additional implemented interfaces, it's just because these frames use task windows.
    
    Prior to LibreOffice 4.3, this singleton was only available as a (single-instance) Desktop service.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API theDesktop <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1frame_1_1theDesktop.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.theDesktop'
    __ooo_type_name__: str = 'singleton'
    _instance = None

    def __new__(cls, *args, **kwargs):
        # single instance only allowed
        if cls._instance is None:
            cls._instance = super().__new__(cls, *args, **kwargs)
        return cls._instance


__all__ = ['theDesktop']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb.tools
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class CompositionType(metaclass=UnoConstMeta, type_name="com.sun.star.sdb.tools.CompositionType", name_space="com.sun.star.sdb.tools"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sdb.tools.CompositionType``"""
        pass

    class CompositionTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sdb.tools.CompositionType", name_space="com.sun.star.sdb.tools"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sdb.tools.CompositionType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.sdb.tools import CompositionType as CompositionType
    else:
        # keep document generators happy
        from ....lo.sdb.tools.composition_type import CompositionType as CompositionType

    class CompositionTypeEnum(IntEnum):
        """
        Enum of Const Class CompositionType

        specifies which composition should be used when composing a table name.
        
        **since**
        
            OOo 2.0.4
        """
        ForTableDefinitions = CompositionType.ForTableDefinitions
        """
        specifies composition of a name to be used in table definitions
        """
        ForIndexDefinitions = CompositionType.ForIndexDefinitions
        """
        specifies composition of a name to be used in index definitions
        """
        ForDataManipulation = CompositionType.ForDataManipulation
        """
        specifies composition of a name to be used in data manipulation
        """
        ForProcedureCalls = CompositionType.ForProcedureCalls
        """
        specifies composition of a name to be used in procedure calls
        """
        ForPrivilegeDefinitions = CompositionType.ForPrivilegeDefinitions
        """
        specifies composition of a name to be used in privilege definitions
        """
        Complete = CompositionType.Complete
        """
        specifies complete composition of a table name, including catalog and schema (if present), disregarding any database support for catalog and schema in any particular statements
        """

__all__ = ['CompositionType', 'CompositionTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
from abc import abstractproperty
from .x_composite_layer import XCompositeLayer as XCompositeLayer_ed7f137e
from ...util.x_time_stamped import XTimeStamped as XTimeStamped_b09b0b7b

class Layer(XCompositeLayer_ed7f137e, XTimeStamped_b09b0b7b):
    """
    Service Class

    provides read-only access to a configuration data layer.
    
    A layer contains the configuration setting changes to be performed on a default settings tree to obtain the values of those settings for a given entity and component.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API Layer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1Layer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.Layer'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def URL(self) -> str:
        """
        The URL of the layer data.
        
        **since**
        
            OOo 2.0
        """
        ...


__all__ = ['Layer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ColorComponentTag(metaclass=UnoConstMeta, type_name="com.sun.star.rendering.ColorComponentTag", name_space="com.sun.star.rendering"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.rendering.ColorComponentTag``"""
        pass

    class ColorComponentTagEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.rendering.ColorComponentTag", name_space="com.sun.star.rendering"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.rendering.ColorComponentTag`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.rendering import ColorComponentTag as ColorComponentTag
    else:
        # keep document generators happy
        from ...lo.rendering.color_component_tag import ColorComponentTag as ColorComponentTag

    class ColorComponentTagEnum(IntEnum):
        """
        Enum of Const Class ColorComponentTag

        A collection of tags for the individual components of a color.
        
        Color components usually correspond to physical attributes like the amount of red colorant contained in an output color. This constant field enumerates the most common ones.
        
        **since**
        
            OOo 2.3
        """
        DEVICE = ColorComponentTag.DEVICE
        """
        Unspecified device color value.
        """
        RGB_RED = ColorComponentTag.RGB_RED
        """
        Red colorant from RGB color space.
        """
        RGB_GREEN = ColorComponentTag.RGB_GREEN
        """
        Green colorant from RGB color space.
        """
        RGB_BLUE = ColorComponentTag.RGB_BLUE
        """
        Blue colorant from RGB color space.
        """
        CMYK_CYAN = ColorComponentTag.CMYK_CYAN
        """
        Cyan colorant from CMYK color space.
        """
        CMYK_MAGENTA = ColorComponentTag.CMYK_MAGENTA
        """
        Magenta colorant from CMYK color space.
        """
        CMYK_YELLOW = ColorComponentTag.CMYK_YELLOW
        """
        Yellow colorant from CMYK color space.
        """
        CMYK_BLACK = ColorComponentTag.CMYK_BLACK
        """
        Black colorant from CMYK color space.
        """
        CMYKOG_ORANGE = ColorComponentTag.CMYKOG_ORANGE
        """
        Orange colorant from hexachrome color space.
        """
        CMYKOG_GREEN = ColorComponentTag.CMYKOG_GREEN
        """
        Green colorant from hexachrome color space.
        """
        SPOT = ColorComponentTag.SPOT
        """
        Arbitrary extra spot color, e.g. Pantone.
        """
        INDEX = ColorComponentTag.INDEX
        """
        Index into palette.
        """
        ALPHA = ColorComponentTag.ALPHA
        """
        Alpha channel.
        """
        GREY = ColorComponentTag.GREY
        """
        Grey value. Used for monochrome color spaces.
        """
        PREMULTIPLIED_ALPHA = ColorComponentTag.PREMULTIPLIED_ALPHA
        """
        Premultiplied alpha channel.
        
        Note that this alpha format actually influences the other color components, in that their values are pre-multiplied with the alpha value.
        """
        CIEXYZ_X = ColorComponentTag.CIEXYZ_X
        """
        CieXYZ X value.
        """
        CIEXYZ_Y = ColorComponentTag.CIEXYZ_Y
        """
        CieXYZ Y value.
        """
        CIEXYZ_Z = ColorComponentTag.CIEXYZ_Z
        """
        CieXYZ Z value.
        """
        CIELAB_L = ColorComponentTag.CIELAB_L
        """
        CieLab L value.
        """
        CIELAB_A = ColorComponentTag.CIELAB_A
        """
        CieLab a value.
        """
        CIELAB_B = ColorComponentTag.CIELAB_B
        """
        CieLab b value.
        """
        HSV_H = ColorComponentTag.HSV_H
        """
        HSV H value.
        """
        HSV_S = ColorComponentTag.HSV_S
        """
        HSV S value.
        """
        HSV_V = ColorComponentTag.HSV_V
        """
        HSV V value.
        """
        HSL_H = ColorComponentTag.HSL_H
        """
        HSL H value.
        """
        HSL_S = ColorComponentTag.HSL_S
        """
        HSL S value.
        """
        HSL_L = ColorComponentTag.HSL_L
        """
        HSL L value.
        """
        YCBCR_Y = ColorComponentTag.YCBCR_Y
        """
        YCbCr Y value.
        """
        YCBCR_CB = ColorComponentTag.YCBCR_CB
        """
        YCbCr Cb value.
        """
        YCBCR_CR = ColorComponentTag.YCBCR_CR
        """
        YCbCr Cr value.
        """

__all__ = ['ColorComponentTag', 'ColorComponentTagEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.deployment
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..uno.exception import Exception as Exception_85530a09
from ..uno.x_interface import XInterface as XInterface_8f010a43
from ..xml.dom.x_element import XElement as XElement_a33d0ae9

class DependencyException(Exception_85530a09):
    """
    Exception Class

    describes unsatisfied dependencies a deployment unit has on its target environment.
    
    This exception is intended to be used with an com.sun.star.task.XInteractionHandler.
    
    **since**
    
        OOo 2.0.4

    See Also:
        `API DependencyException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1deployment_1_1DependencyException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.deployment'
    __ooo_full_ns__: str = 'com.sun.star.deployment.DependencyException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.deployment.DependencyException'
    __pyunostruct__: str = 'com.sun.star.deployment.DependencyException'

    typeName: str = 'com.sun.star.deployment.DependencyException'
    """Literal Constant ``com.sun.star.deployment.DependencyException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, UnsatisfiedDependencies: typing.Optional[typing.Tuple[XElement_a33d0ae9, ...]] = ()) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            UnsatisfiedDependencies (typing.Tuple[XElement, ...], optional): UnsatisfiedDependencies value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "UnsatisfiedDependencies": UnsatisfiedDependencies,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._unsatisfied_dependencies = kwargs["UnsatisfiedDependencies"]
        inst_keys = ('UnsatisfiedDependencies',)
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def UnsatisfiedDependencies(self) -> typing.Tuple[XElement_a33d0ae9, ...]:
        """
        a sequence of dependencies represented by XML elements.
        
        The exact nature of those XML elements is deliberately left open, so that new kinds of dependencies can be defined in the future. OOo 2.0.4 does not define any kinds of dependencies. Each such XML element should have an attribute whose global name consists of the namespace name http://openoffice.org/extensions/description/2006 and the local part name and whose value is a human-readable (English) description of the dependency. If an instance of OOo does not know more about a specific kind of dependency, it should display the value of that attribute to the user.
        
        The sequence must not be empty, and none of the elements may be NULL.
        """
        return self._unsatisfied_dependencies
    
    @UnsatisfiedDependencies.setter
    def UnsatisfiedDependencies(self, value: typing.Tuple[XElement_a33d0ae9, ...]) -> None:
        self._unsatisfied_dependencies = value


__all__ = ['DependencyException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from abc import abstractproperty
from .column_settings import ColumnSettings as ColumnSettings_bbba0c00
from ..sdbcx.column import Column as Column_7b1d098a

class ResultColumn(ColumnSettings_bbba0c00, Column_7b1d098a):
    """
    Service Class

    describes a column of a result set.

    See Also:
        `API ResultColumn <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1ResultColumn.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.ResultColumn'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CatalogName(self) -> str:
        """
        gets a column's table's catalog name.
        """
        ...

    @abstractproperty
    def DisplaySize(self) -> int:
        """
        indicates the column's normal max width in chars.
        """
        ...

    @abstractproperty
    def IsCaseSensitive(self) -> bool:
        """
        indicates that a column is case sensitive.
        """
        ...

    @abstractproperty
    def IsDefinitelyWritable(self) -> bool:
        """
        indicates whether a write on the column will definitely succeed.
        """
        ...

    @abstractproperty
    def IsReadOnly(self) -> bool:
        """
        indicates whether a column is definitely, not writable.
        """
        ...

    @abstractproperty
    def IsSearchable(self) -> bool:
        """
        indicates whether the column can be used in a Where clause.
        """
        ...

    @abstractproperty
    def IsSigned(self) -> bool:
        """
        indicates whether values in the column are signed numbers.
        """
        ...

    @abstractproperty
    def IsWritable(self) -> bool:
        """
        indicates whether it is possible for a write on the column to succeed.
        """
        ...

    @abstractproperty
    def Label(self) -> str:
        """
        gets the suggested column title for use in printouts and displays.
        """
        ...

    @abstractproperty
    def SchemaName(self) -> str:
        """
        gets a column's schema name.
        """
        ...

    @abstractproperty
    def ServiceName(self) -> str:
        """
        returns the fully-qualified name of the service whose instances are manufactured if the method com.sun.star.sdbc.XRow.getObject)= is called to retrieve a value from the column.
        """
        ...

    @abstractproperty
    def TableName(self) -> str:
        """
        gets a column's table name.
        """
        ...


__all__ = ['ResultColumn']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.view
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class PaperFormat(Enum):
    """
    Enum Class


    See Also:
        `API PaperFormat <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1view.html#a12ab04987d08416f8347a9790c7abf3e>`_
    """
    __ooo_ns__: str = "com.sun.star.view"
    __ooo_full_ns__: str = "com.sun.star.view.PaperFormat"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.view.PaperFormat"

    A3 = "A3"
    """
    specifies the paper format as A3.
    """
    A4 = "A4"
    """
    specifies the paper format as A4.
    """
    A5 = "A5"
    """
    specifies the paper format as A5.
    """
    B4 = "B4"
    """
    specifies the paper format as B4.
    """
    B5 = "B5"
    """
    specifies the paper format as B5.
    """
    LEGAL = "LEGAL"
    """
    specifies the paper format as Legal.
    """
    LETTER = "LETTER"
    """
    specifies the paper format as Letter.
    """
    TABLOID = "TABLOID"
    """
    specifies the paper format as Tabloid.
    """
    USER = "USER"
    """
    The real paper size is user defined in 100th mm.
    """

__all__ = ["PaperFormat"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..lang.x_component import XComponent as XComponent_98dc0ab5

class XComponentLoader(XInterface_8f010a43):
    """
    this is a simple interface to load components by a URL into a frame environment

    See Also:
        `API XComponentLoader <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XComponentLoader.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XComponentLoader'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XComponentLoader'

    @abstractmethod
    def loadComponentFromURL(self, URL: str, TargetFrameName: str, SearchFlags: int, Arguments: typing.Tuple[PropertyValue_c9610c73, ...]) -> XComponent_98dc0ab5:
        """
        loads a component specified by a URL into the specified new or existing frame.
        
        To create new documents, use \"private:factory/scalc\", \"private:factory/swriter\", etc. Other special protocols (e.g. \"slot:\", \".uno\") are not allowed and raise a com.sun.star.lang.IllegalArgumentException.
        
        If a frame with the specified name already exists, it is used, otherwise it is created. There exist some special targets which never can be used as real frame names:
        
        Note: These flags are optional ones and will be used for non special target names only.
        
        For example, \"ReadOnly\" with a boolean value specifies whether the document is opened read-only. \"FilterName\" specifies the component type to create and the filter to use, for example: \"Text - CSV\". For more information see com.sun.star.document.MediaDescriptor.
        
        This interface is a generic one and can be used to start further requests on loaded document or control the lifetime of it (means dispose() it after using). The real document service behind this interface can be one of follow three ones:

        Raises:
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XComponentLoader']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from .x_batch_execution import XBatchExecution as XBatchExecution_d1eb0c92
from .x_closeable import XCloseable as XCloseable_98290a86
from .x_multiple_results import XMultipleResults as XMultipleResults_e1b50d3a
from .x_statement import XStatement as XStatement_98e90ab1
from .x_warnings_supplier import XWarningsSupplier as XWarningsSupplier_ef210d99
from ..util.x_cancellable import XCancellable as XCancellable_afc30b64

class Statement(XPropertySet_bc180bfa, XComponent_98dc0ab5, XBatchExecution_d1eb0c92, XCloseable_98290a86, XMultipleResults_e1b50d3a, XStatement_98e90ab1, XWarningsSupplier_ef210d99, XCancellable_afc30b64):
    """
    Service Class

    is used for executing a static SQL statement and obtaining the results produced by it.
    
    Only one ResultSet per Statement can be open at any point in time. Therefore, if the reading of one ResultSet is interleaved with the reading of another, each must have been generated by different Statements. All statement execute methods implicitly close a statement's current ResultSet if an open one exists.

    See Also:
        `API Statement <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbc_1_1Statement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.Statement'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CursorName(self) -> str:
        """
        defines the SQL cursor name that will be used by subsequent Statement execute methods.
        
        This name can then be used in SQL positioned update/delete statements to identify the current row in the ResultSet generated by this statement. If the database does not support positioned update/delete, this property is a noop. To ensure that a cursor has the proper isolation level to support updates, the cursor's SELECT statement should be of the form \"select for update ...\". If the \"for update\" phrase is omitted, positioned updates may fail.
        
        Note:  By definition, positioned update/delete execution must be done by a different Statement than the one which generated the ResultSet being used for positioning. Also, cursor names must be unique within a connection.
        """
        ...

    @abstractproperty
    def EscapeProcessing(self) -> bool:
        """
        returns if escape processing is on or off.
        
        If escape scanning is on (the default), the driver will do escape substitution before sending the SQL to the database.
        """
        ...

    @abstractproperty
    def FetchDirection(self) -> int:
        """
        retrieves the direction for fetching rows from database tables that is the default for result sets generated from this Statement object.
        
        If this Statement object has not set a fetch direction, the return value is implementation-specific.
        """
        ...

    @abstractproperty
    def FetchSize(self) -> int:
        """
        retrieves the number of result set rows that is the default fetch size for result sets generated from this Statement object.
        
        If this Statement object has not set a fetch size, the return value is implementation-specific.
        """
        ...

    @abstractproperty
    def MaxFieldSize(self) -> int:
        """
        returns the maximum number of bytes allowed for any column value.
        
        This limit is the maximum number of bytes that can be returned for any column value. The limit applies only to com.sun.star.sdbc.DataType.BINARY , com.sun.star.sdbc.DataType.VARBINARY , com.sun.star.sdbc.DataType.LONGVARBINARY , com.sun.star.sdbc.DataType.CHAR , com.sun.star.sdbc.DataType.VARCHAR , and com.sun.star.sdbc.DataType.LONGVARCHAR columns. If the limit is exceeded, the excess data is silently discarded. There is no limitation, if set to zero.
        """
        ...

    @abstractproperty
    def MaxRows(self) -> int:
        """
        retrieves the maximum number of rows that a ResultSet can contain.
        
        If the limit is exceeded, the excess rows are silently dropped. There is no limitation, if set to zero.
        """
        ...

    @abstractproperty
    def QueryTimeOut(self) -> int:
        """
        retrieves the number of seconds the driver will wait for a Statement to execute.
        
        If the limit is exceeded, a SQLException is thrown. There is no limitation, if set to zero.
        """
        ...

    @abstractproperty
    def ResultSetConcurrency(self) -> int:
        """
        retrieves the result set concurrency.
        """
        ...

    @abstractproperty
    def ResultSetType(self) -> int:
        """
        determine the result set type.
        """
        ...


__all__ = ['Statement']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .flag_sequence_sequence import FlagSequenceSequence as FlagSequenceSequence_49130fe0
from .point_sequence_sequence import PointSequenceSequence as PointSequenceSequence_5c591070


class PolyPolygonBezierCoords(object):
    """
    Struct Class

    specifies the coordinates for a poly polygon Bezier.

    See Also:
        `API PolyPolygonBezierCoords <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonBezierCoords.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.PolyPolygonBezierCoords'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.drawing.PolyPolygonBezierCoords'
    """Literal Constant ``com.sun.star.drawing.PolyPolygonBezierCoords``"""

    def __init__(self, Coordinates: typing.Optional[PointSequenceSequence_5c591070] = PointSequenceSequence_5c591070(()), Flags: typing.Optional[FlagSequenceSequence_49130fe0] = FlagSequenceSequence_49130fe0(())) -> None:
        """
        Constructor

        Arguments:
            Coordinates (PointSequenceSequence, optional): Coordinates value.
            Flags (FlagSequenceSequence, optional): Flags value.
        """
        super().__init__()

        if isinstance(Coordinates, PolyPolygonBezierCoords):
            oth: PolyPolygonBezierCoords = Coordinates
            self.Coordinates = oth.Coordinates
            self.Flags = oth.Flags
            return

        kargs = {
            "Coordinates": Coordinates,
            "Flags": Flags,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._coordinates = kwargs["Coordinates"]
        self._flags = kwargs["Flags"]


    @property
    def Coordinates(self) -> PointSequenceSequence_5c591070:
        return self._coordinates

    @Coordinates.setter
    def Coordinates(self, value: PointSequenceSequence_5c591070) -> None:
        self._coordinates = value

    @property
    def Flags(self) -> FlagSequenceSequence_49130fe0:
        return self._flags

    @Flags.setter
    def Flags(self, value: FlagSequenceSequence_49130fe0) -> None:
        self._flags = value


__all__ = ['PolyPolygonBezierCoords']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering


class RenderingIntent(object):
    """
    Const Class

    The rendering intent for a color space.
    
    The rendering intent for a color space mostly determines how out-of-gamut color is treated. See Wikipedia for a thorough explanation.
    
    **since**
    
        OOo 2.0

    See Also:
        `API RenderingIntent <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1RenderingIntent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.RenderingIntent'
    __ooo_type_name__: str = 'const'

    PERCEPTUAL = 0
    """
    Also known as the image intent, this rendering intent aims to preserve the visual relationship between colors in a way that is perceived as natural to the human eye, although the color values themselves may change.
    
    This intent is most suitable for photographic images.
    """
    SATURATION = 1
    """
    The rendering intent for business graphics that maintains vivid color at the expense of accurate color.
    
    It scales the source gamut to the destination gamut but preserves relative saturation instead of hue, so when scaling to a smaller gamut, hues may shift. This rendering intent is primarily designed for business graphics, where bright saturated colors are more important than the exact relationship between colors (such as in a photographic image).
    """
    RELATIVE_COLORIMETRIC = 2
    """
    The rendering intent almost identical to Absolute Colorimetric except for the following difference: Relative Colorimetric compares the white point (extreme highlight) of the source color space to that of the destination color space and shifts all colors accordingly.
    """
    ABSOLUTE_COLORIMETRIC = 3
    """
    The rendering intent that leaves colors that fall inside the destination gamut unchanged.
    
    Out of gamut colors are clipped. No scaling of colors to destination white point is performed. This intent aims to maintain color accuracy at the expense of preserving relationships between colors, and is useful for seeing how output will look on a non-neutral substrate.
    """

__all__ = ['RenderingIntent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from .....lo.text.textfield.docinfo.change_author import ChangeAuthor as ChangeAuthor
from .....lo.text.textfield.docinfo.change_date_time import ChangeDateTime as ChangeDateTime
from .....lo.text.textfield.docinfo.create_author import CreateAuthor as CreateAuthor
from .....lo.text.textfield.docinfo.create_date_time import CreateDateTime as CreateDateTime
from .....lo.text.textfield.docinfo.custom import Custom as Custom
from .....lo.text.textfield.docinfo.description import Description as Description
from .....lo.text.textfield.docinfo.edit_time import EditTime as EditTime
from .....lo.text.textfield.docinfo.keywords import Keywords as Keywords
from .....lo.text.textfield.docinfo.print_author import PrintAuthor as PrintAuthor
from .....lo.text.textfield.docinfo.print_date_time import PrintDateTime as PrintDateTime
from .....lo.text.textfield.docinfo.revision import Revision as Revision
from .....lo.text.textfield.docinfo.subject import Subject as Subject
from .....lo.text.textfield.docinfo.title import Title as Title



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d

class ItemDescriptor(ABC):
    """
    Service Class

    describes a user interface item that is part of a user interface element.
    
    Common examples for such elements are:
    
    No assumption is made about any graphical representation: You could have a menu or a toolbox working with the same item descriptor.
    
    **since**
    
        OOo 2.0

    See Also:
        `API ItemDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1ItemDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.ItemDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CommandURL(self) -> str:
        """
        contains the command URL which specifies which action should be accomplished.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        contains the a URL that points to a help text.
        """
        ...

    @abstractproperty
    def IsVisible(self) -> bool:
        """
        specifies if this item is visible or not.
        
        This property is only valid if the item describes a toolbar or statusbar item.
        """
        ...

    @abstractproperty
    def ItemDescriptorContainer(self) -> XIndexAccess_f0910d6d:
        """
        specifies an optional sub container.
        
        This property is valid for menus only. It can be used to define sub menus.
        """
        ...

    @abstractproperty
    def Label(self) -> str:
        """
        the text of the user interface item.
        """
        ...

    @abstractproperty
    def Offset(self) -> int:
        """
        specifies the pixel distance by which the text of the item is shifted on the x-axis.
        
        This property is only valid if the item describes a statusbar item.
        """
        ...

    @abstractproperty
    def Style(self) -> int:
        """
        different styles which influence the appearance of the item and its behavior.
        
        This property is only valid if the item describes a toolbar or statusbar item. See ItemStyle for more information about possible styles.
        """
        ...

    @abstractproperty
    def Type(self) -> int:
        """
        specifies which type this item descriptor belongs to.
        
        See constant definition ItemType.
        """
        ...

    @abstractproperty
    def Width(self) -> int:
        """
        specifies a pixel width for this item inside the user interface element.
        
        This property is only valid if the item describes a toolbar or statusbar item.
        """
        ...


__all__ = ['ItemDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.geometry
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class IntegerSize2D(object):
    """
    Struct Class

    This structure contains data representing a two-dimensional size.
    
    The data is stored integer-valued.
    
    **since**
    
        OOo 2.0

    See Also:
        `API IntegerSize2D <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1geometry_1_1IntegerSize2D.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.geometry'
    __ooo_full_ns__: str = 'com.sun.star.geometry.IntegerSize2D'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.geometry.IntegerSize2D'
    """Literal Constant ``com.sun.star.geometry.IntegerSize2D``"""

    def __init__(self, Width: typing.Optional[int] = 0, Height: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Width (int, optional): Width value.
            Height (int, optional): Height value.
        """
        super().__init__()

        if isinstance(Width, IntegerSize2D):
            oth: IntegerSize2D = Width
            self.Width = oth.Width
            self.Height = oth.Height
            return

        kargs = {
            "Width": Width,
            "Height": Height,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._width = kwargs["Width"]
        self._height = kwargs["Height"]


    @property
    def Width(self) -> int:
        """
        Amount of space occupied in the x direction.
        """
        return self._width

    @Width.setter
    def Width(self, value: int) -> None:
        self._width = value

    @property
    def Height(self) -> int:
        """
        Amount of space occupied in the y direction.
        """
        return self._height

    @Height.setter
    def Height(self, value: int) -> None:
        self._height = value


__all__ = ['IntegerSize2D']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text.textfield
from __future__ import annotations
from abc import abstractproperty
from ..dependent_text_field import DependentTextField as DependentTextField_fed90ded

class Database(DependentTextField_fed90ded):
    """
    Service Class

    specifies service of a database text field which is used as mail merge field.

    See Also:
        `API Database <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1Database.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text.textfield'
    __ooo_full_ns__: str = 'com.sun.star.text.textfield.Database'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Content(self) -> str:
        """
        contains the database content that was merged in the last database merge action.
        
        Initially it contains the column name in parenthesis (<>).
        """
        ...

    @abstractproperty
    def CurrentPresentation(self) -> str:
        """
        contains the current content of the text field.
        
        This property is especially useful for import/export purposes.
        """
        ...

    @abstractproperty
    def DataBaseFormat(self) -> bool:
        """
        determines whether the number format is number display format is read from the database settings.
        """
        ...

    @abstractproperty
    def NumberFormat(self) -> int:
        """
        this is the number format for this field.
        """
        ...


__all__ = ['Database']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from ..chart.x_chart_data_array import XChartDataArray as XChartDataArray_df4c0cdd
from ..sheet.x_cell_range_data import XCellRangeData as XCellRangeData_d2e70c60
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb
from ..style.paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
from ..style.paragraph_properties_asian import ParagraphPropertiesAsian as ParagraphPropertiesAsian_6e8c10e8
from ..style.paragraph_properties_complex import ParagraphPropertiesComplex as ParagraphPropertiesComplex_91de11d4
from ..table.x_cell_range import XCellRange as XCellRange_a2f70ad5
if typing.TYPE_CHECKING:
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.style.GraphicLocation import GraphicLocationProto  # type: ignore

class CellRange(CharacterProperties_1d4f0ef3, CharacterPropertiesAsian_6d8a10df, CharacterPropertiesComplex_90ca11cb, ParagraphProperties_1e240efc, ParagraphPropertiesAsian_6e8c10e8, ParagraphPropertiesComplex_91de11d4, XChartDataArray_df4c0cdd, XCellRangeData_d2e70c60, XCellRange_a2f70ad5):
    """
    Service Class

    area of cells within a text table.
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API CellRange <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1CellRange.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.CellRange'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BackColor(self) -> Color_68e908c5:
        """
        contains color of the background.
        """
        ...

    @abstractproperty
    def BackGraphic(self) -> XGraphic_a4da0afc:
        """
        contains the graphic of the background.
        
        **since**
        
            LibreOffice 6.1
        """
        ...

    @abstractproperty
    def BackGraphicFilter(self) -> str:
        """
        contains the filter name of the background graphic.
        """
        ...

    @abstractproperty
    def BackGraphicLocation(self) -> GraphicLocationProto:
        """
        determines the location of the background graphic.
        """
        ...

    @abstractproperty
    def BackGraphicURL(self) -> str:
        """
        contains the URL of the background graphic.
        
        Note the new behaviour since it this was deprecated: This property can only be set and only external URLs are supported (no more vnd.sun.star.GraphicObject scheme). When an URL is set, then it will load the graphic and set the BackGraphic property.
        """
        ...

    @abstractproperty
    def BackTransparent(self) -> bool:
        """
        determines if the background color is transparent.
        """
        ...

    @abstractproperty
    def ChartColumnAsLabel(self) -> bool:
        """
        determines if the first column of the table should be treated as axis labels when a chart is to be created.
        """
        ...

    @abstractproperty
    def ChartRowAsLabel(self) -> bool:
        """
        determines if the first row of the table should be treated as axis labels when a chart is to be created.
        """
        ...

    @abstractproperty
    def NumberFormat(self) -> int:
        """
        contains the number format.
        """
        ...


__all__ = ['CellRange']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations
from __future__ import annotations
import typing
from abc import abstractproperty
from ..container.x_child import XChild as XChild_a6390b07
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3

class XAnimationNode(XChild_a6390b07):
    """

    See Also:
        `API XAnimationNode <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1animations_1_1XAnimationNode.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.animations'
    __ooo_full_ns__: str = 'com.sun.star.animations.XAnimationNode'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.animations.XAnimationNode'

    @abstractproperty
    def UserData(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        """
        ...

    @abstractproperty
    def Acceleration(self) -> float:
        """
        defines the acceleration for this element.
        
        Element time will accelerate from a rate of 0 at the beginning up to a run rate, over the course of the specified proportion of the simple duration.
        
        Acceleration is a value between 0 (no acceleration) and 1 (acceleration until end of the elements duration).
        """
        ...

    @abstractproperty
    def AutoReverse(self) -> bool:
        """
        defines the auto reverse settings for this element.
        
        AutoReverse is
        """
        ...

    @abstractproperty
    def Begin(self) -> object:
        """
        a sequence of values that define the beginning of this element Begin is
        """
        ...

    @abstractproperty
    def Decelerate(self) -> float:
        """
        defines the deceleration for this element.
        
        Element time will deceleration from a run rate to a rate of 0 at the ending, over the course of the specified proportion of the simple duration.
        
        Decelerate is a value between 0 (no deceleration) and 1 (deceleration from beginning of the elements duration).
        """
        ...

    @abstractproperty
    def Duration(self) -> object:
        """
        defines the length of the simple duration.
        
        Duration is
        """
        ...

    @abstractproperty
    def End(self) -> object:
        """
        a sequence of values that define the ending of this element End is
        """
        ...

    @abstractproperty
    def EndSync(self) -> object:
        """
        controls the implicit duration of time containers, as a function of the children.
        
        The EndSync attribute is only valid for par and excl time container elements, and media elements with timed children (e.g. animate or area elements).
        
        EndSync is either a short constant from EndSync, an interface reference to a child XTimeContainer or VOID.
        """
        ...

    @abstractproperty
    def Fill(self) -> int:
        """
        the attribute that specify the behavior how an element should be extended beyond the active duration by freezing the final state of the element.
        
        Fill is a value from AnimationFill.
        """
        ...

    @abstractproperty
    def FillDefault(self) -> int:
        """
        the default value for the fill behavior for this element and all descendants.
        
        FillDefault is
        """
        ...

    @abstractproperty
    def RepeatCount(self) -> object:
        """
        the number of iterations of the simple duration.
        
        RepeatCount is
        """
        ...

    @abstractproperty
    def RepeatDuration(self) -> object:
        """
        the total duration for repeat.
        
        RepeatDuration is
        """
        ...

    @abstractproperty
    def Restart(self) -> int:
        """
        defines the restart behavior of this element.
        
        Restart is a short value from AnimationRestart.
        """
        ...

    @abstractproperty
    def RestartDefault(self) -> int:
        """
        defines the default restart behavior for this element and all descendants.
        """
        ...

    @abstractproperty
    def Type(self) -> int:
        """
        a value from AnimationNodeType.
        """
        ...


__all__ = ['XAnimationNode']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from ..task.x_interaction_handler2 import XInteractionHandler2 as XInteractionHandler2_1a7b0e83

class DatabaseInteractionHandler(XInteractionHandler2_1a7b0e83):
    """
    Service Class

    describes a service which is able to handle database-related interactions.
    
    Usually, you will not instantiate this service directly. Instead, you'll instantiate a generic com.sun.star.task.InteractionHandler service, and pass it your request. Based on configuration data, this implementation will decide where to forward the request to.
    
    By default, the DatabaseInteractionHandler feels responsible (as per configuration) for the following interaction types:

    See Also:
        `API DatabaseInteractionHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseInteractionHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DatabaseInteractionHandler'
    __ooo_type_name__: str = 'service'


__all__ = ['DatabaseInteractionHandler']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_model import XModel as XModel_7a6e095c
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..container.x_enumeration import XEnumeration as XEnumeration_f2180daa
    from .x_controller2 import XController2 as XController2_bbcf0bc1
    from .x_frame import XFrame as XFrame_7a570956

class XModel2(XModel_7a6e095c):
    """
    extends interface XModel.
    
    The following functions are added:
    
    **since**
    
        LibreOffice 6.3

    See Also:
        `API XModel2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XModel2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XModel2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XModel2'

    @abstractmethod
    def createDefaultViewController(self, Frame: XFrame_7a570956) -> XController2_bbcf0bc1:
        """
        creates the default view instance for this model.
        
        Effectively, this method is equivalent to calling createView() with the ViewName being \"Default\".

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def createViewController(self, ViewName: str, Arguments: typing.Tuple[PropertyValue_c9610c73, ...], Frame: XFrame_7a570956) -> XController2_bbcf0bc1:
        """
        creates a new view instance classified by the specified name and arguments.
        
        The newly created controller must not be connected with the document and the frame. That is, you should neither call XFrame.setComponent(), nor XController.attachFrame(), nor XController.attachModel(), nor XModel.connectController(), not XModel.setCurrentController(). All of this is the responsibility of the caller, which will do it in the proper order.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def getAvailableViewControllerNames(self) -> typing.Tuple[str, ...]:
        """
        provides the available names of the factory to be used to create views.
        
        The names are usually logical view names. The following names have a defined meaning, i.e. every concrete implementation which returns such a name must ensure it has the same meaning, and if a concrete implementation has a view with the given meaning, it must give it the name as defined here:
        
        Implementations of this interface might decide to support additional view names, which then are documented in the respective service descriptions.
        """
        ...
    @abstractmethod
    def getControllers(self) -> XEnumeration_f2180daa:
        """
        provides list of all currently connected controller objects.
        
        Please note: Because this interface will might be used inside multi threaded environments those list can contain still disposed items or it new added controller will be missing (if they were added after this enumeration was created).
        """
        ...
    @abstractmethod
    def setArgs(self, Arguments: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        Sets com.sun.star.document.MediaDescriptor properties of the current model during runtime.
        
        **since**
        
            LibreOffice 6.3

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.util.InvalidStateException: ``InvalidStateException``
        """
        ...

__all__ = ['XModel2']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.table
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..util.color import Color as Color_68e908c5


class BorderLine(object):
    """
    Struct Class

    describes the line type for a single cell edge.

    See Also:
        `API BorderLine <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1table_1_1BorderLine.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.BorderLine'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.table.BorderLine'
    """Literal Constant ``com.sun.star.table.BorderLine``"""

    def __init__(self, Color: typing.Optional[Color_68e908c5] = Color_68e908c5(0), InnerLineWidth: typing.Optional[int] = 0, OuterLineWidth: typing.Optional[int] = 0, LineDistance: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Color (Color, optional): Color value.
            InnerLineWidth (int, optional): InnerLineWidth value.
            OuterLineWidth (int, optional): OuterLineWidth value.
            LineDistance (int, optional): LineDistance value.
        """
        super().__init__()

        if isinstance(Color, BorderLine):
            oth: BorderLine = Color
            self.Color = oth.Color
            self.InnerLineWidth = oth.InnerLineWidth
            self.OuterLineWidth = oth.OuterLineWidth
            self.LineDistance = oth.LineDistance
            return

        kargs = {
            "Color": Color,
            "InnerLineWidth": InnerLineWidth,
            "OuterLineWidth": OuterLineWidth,
            "LineDistance": LineDistance,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._color = kwargs["Color"]
        self._inner_line_width = kwargs["InnerLineWidth"]
        self._outer_line_width = kwargs["OuterLineWidth"]
        self._line_distance = kwargs["LineDistance"]


    @property
    def Color(self) -> Color_68e908c5:
        """
        contains the color value of the line.
        """
        return self._color

    @Color.setter
    def Color(self, value: Color_68e908c5) -> None:
        self._color = value

    @property
    def InnerLineWidth(self) -> int:
        """
        contains the width of the inner part of a double line (in 1/100 mm).
        
        If this value is zero, only a single line is drawn.
        """
        return self._inner_line_width

    @InnerLineWidth.setter
    def InnerLineWidth(self, value: int) -> None:
        self._inner_line_width = value

    @property
    def OuterLineWidth(self) -> int:
        """
        contains the width of a single line or the width of outer part of a double line (in 1/100 mm).
        
        If this value is zero, no line is drawn.
        """
        return self._outer_line_width

    @OuterLineWidth.setter
    def OuterLineWidth(self, value: int) -> None:
        self._outer_line_width = value

    @property
    def LineDistance(self) -> int:
        """
        contains the distance between the inner and outer parts of a double line (in 1/100 mm).
        """
        return self._line_distance

    @LineDistance.setter
    def LineDistance(self, value: int) -> None:
        self._line_distance = value


__all__ = ['BorderLine']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ErrorBarStyle(metaclass=UnoConstMeta, type_name="com.sun.star.chart.ErrorBarStyle", name_space="com.sun.star.chart"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.chart.ErrorBarStyle``"""
        pass

    class ErrorBarStyleEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.chart.ErrorBarStyle", name_space="com.sun.star.chart"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.chart.ErrorBarStyle`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.chart import ErrorBarStyle as ErrorBarStyle
    else:
        # keep document generators happy
        from ...lo.chart.error_bar_style import ErrorBarStyle as ErrorBarStyle

    class ErrorBarStyleEnum(IntEnum):
        """
        Enum of Const Class ErrorBarStyle

        specifies the style of error indicators.
        """
        NONE = ErrorBarStyle.NONE
        """
        error indicators are not displayed.
        """
        VARIANCE = ErrorBarStyle.VARIANCE
        """
        displays error indicators for the variance of the data.
        """
        STANDARD_DEVIATION = ErrorBarStyle.STANDARD_DEVIATION
        """
        displays error indicators for the standard deviation (square root of variance) of the data.
        """
        ABSOLUTE = ErrorBarStyle.ABSOLUTE
        """
        the error indicators for all data points have the same absolute value as length for either direction.
        
        The values for these are given as absolute numbers in ChartStatistics.ConstantErrorLow and ChartStatistics.ConstantErrorHigh
        """
        RELATIVE = ErrorBarStyle.RELATIVE
        """
        The length of the error indicators is calculated for each data point by taking the percentage given as ChartStatistics.PercentageError of its value.
        """
        ERROR_MARGIN = ErrorBarStyle.ERROR_MARGIN
        """
        The length of the error indicators for all data points is calculated by taking the percentage given as ChartStatistics.ErrorMargin of the largest data point value.
        """
        STANDARD_ERROR = ErrorBarStyle.STANDARD_ERROR
        """
        displays error indicators for the standard error, also known as the standard deviation of the mean (SDOM).
        """
        FROM_DATA = ErrorBarStyle.FROM_DATA
        """
        Uses values given by cell ranges of the container document.
        
        The values for the cell ranges are given in the properties ChartStatistics.ErrorBarRangePositive for positive indicators and ChartStatistics.ErrorBarRangeNegative for negative indicators.
        """

__all__ = ['ErrorBarStyle', 'ErrorBarStyleEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ElementModes(metaclass=UnoConstMeta, type_name="com.sun.star.embed.ElementModes", name_space="com.sun.star.embed"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.embed.ElementModes``"""
        pass

    class ElementModesEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.embed.ElementModes", name_space="com.sun.star.embed"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.embed.ElementModes`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.embed import ElementModes as ElementModes
    else:
        # keep document generators happy
        from ...lo.embed.element_modes import ElementModes as ElementModes

    class ElementModesEnum(IntEnum):
        """
        Enum of Const Class ElementModes

        The constant set contains possible modes to open an element.
        
        The modes can be combined by \"or\" operation. ElementModes.READ and ElementModes.WRITE are base modes. A result mode must include one of base modes.
        """
        READ = ElementModes.READ
        """
        specifies opening of an element for reading.
        """
        SEEKABLE = ElementModes.SEEKABLE
        """
        specifies opening of a seekable element.
        
        This mode is ignored for Storage elements. This flag makes sense only in combination with ElementModes.READ and/or ElementModes.WRITE.
        """
        SEEKABLEREAD = ElementModes.SEEKABLEREAD
        """
        specifies opening of a seekable element for reading.
        
        This is just a combination of the previous two values. For storages it is the same as ElementModes.READ.
        """
        WRITE = ElementModes.WRITE
        """
        specifies opening of an element for writing.
        """
        READWRITE = ElementModes.READWRITE
        """
        specifies opening of an element for reading and writing.
        
        For a stream element is also specifies that it must be seekable.
        """
        TRUNCATE = ElementModes.TRUNCATE
        """
        lets the document be truncated immediately after opening.
        
        This flag makes sense only in combination with ElementModes.WRITE.
        """
        NOCREATE = ElementModes.NOCREATE
        """
        restricts creation of a new element on opening in case a requested one does not exist.
        
        This flag makes sense only in combination with ElementModes.WRITE.
        """

__all__ = ['ElementModes', 'ElementModesEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.dom
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_node import XNode as XNode_83fb09a5
if typing.TYPE_CHECKING:
    from .x_element import XElement as XElement_a33d0ae9

class XAttr(XNode_83fb09a5):
    """

    See Also:
        `API XAttr <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XAttr.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.dom'
    __ooo_full_ns__: str = 'com.sun.star.xml.dom.XAttr'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.dom.XAttr'

    @abstractmethod
    def getName(self) -> str:
        """
        Returns the name of this attribute.
        """
        ...
    @abstractmethod
    def getOwnerElement(self) -> XElement_a33d0ae9:
        """
        The Element node this attribute is attached to or null if this attribute is not in use.
        """
        ...
    @abstractmethod
    def getSpecified(self) -> bool:
        """
        If this attribute was explicitly given a value in the original document, this is true; otherwise, it is false.
        """
        ...
    @abstractmethod
    def getValue(self) -> str:
        """
        On retrieval, the value of the attribute is returned as a string.
        """
        ...
    @abstractmethod
    def setValue(self, value: str) -> None:
        """
        Sets the value of the attribute from a string.
        
        Throws: DOMException - NO_MODIFICATION_ALLOWED_ERR: Raised when the node is readonly.

        Raises:
            DOMException: ``DOMException``
        """
        ...

__all__ = ['XAttr']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class GeneralFunction2(metaclass=UnoConstMeta, type_name="com.sun.star.sheet.GeneralFunction2", name_space="com.sun.star.sheet"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sheet.GeneralFunction2``"""
        pass

    class GeneralFunction2Enum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sheet.GeneralFunction2", name_space="com.sun.star.sheet"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sheet.GeneralFunction2`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.sheet import GeneralFunction2 as GeneralFunction2
    else:
        # keep document generators happy
        from ...lo.sheet.general_function2 import GeneralFunction2 as GeneralFunction2

    class GeneralFunction2Enum(IntEnum):
        """
        Enum of Const Class GeneralFunction2

        used to specify a function to be calculated from values.
        
        **since**
        
            LibreOffice 5.3
        """
        NONE = GeneralFunction2.NONE
        """
        nothing is calculated.
        """
        AUTO = GeneralFunction2.AUTO
        """
        function is determined automatically.
        
        If the values are all numerical, SUM is used, otherwise COUNT.
        """
        SUM = GeneralFunction2.SUM
        """
        sum of all numerical values is calculated.
        """
        COUNT = GeneralFunction2.COUNT
        """
        all values, including non-numerical values, are counted.
        """
        AVERAGE = GeneralFunction2.AVERAGE
        """
        average of all numerical values is calculated.
        """
        MAX = GeneralFunction2.MAX
        """
        maximum value of all numerical values is calculated.
        """
        MIN = GeneralFunction2.MIN
        """
        minimum value of all numerical values is calculated.
        """
        PRODUCT = GeneralFunction2.PRODUCT
        """
        product of all numerical values is calculated.
        """
        COUNTNUMS = GeneralFunction2.COUNTNUMS
        """
        numerical values are counted.
        """
        STDEV = GeneralFunction2.STDEV
        """
        standard deviation is calculated based on a sample.
        """
        STDEVP = GeneralFunction2.STDEVP
        """
        standard deviation is calculated based on the entire population.
        """
        VAR = GeneralFunction2.VAR
        """
        variance is calculated based on a sample.
        """
        VARP = GeneralFunction2.VARP
        """
        variance is calculated based on the entire population.
        """
        MEDIAN = GeneralFunction2.MEDIAN
        """
        median of all numerical values is calculated.
        
        **since**
        
            LibreOffice 5.3
        """

__all__ = ['GeneralFunction2', 'GeneralFunction2Enum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
if typing.TYPE_CHECKING:
    from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
    from ..table.cell_range_address import CellRangeAddress as CellRangeAddress_ec450d43

class XSheetCellRanges(XIndexAccess_f0910d6d):
    """
    provides methods to access cell ranges in a collection via index and other helper methods.

    See Also:
        `API XSheetCellRanges <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCellRanges.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XSheetCellRanges'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XSheetCellRanges'

    @abstractmethod
    def getCells(self) -> XEnumerationAccess_4bac0ffc:
        """
        returns the collection of all used cells.
        """
        ...
    @abstractmethod
    def getRangeAddresses(self) -> typing.Tuple[CellRangeAddress_ec450d43, ...]:
        """
        creates a sequence with addresses of all contained cell ranges.
        """
        ...
    @abstractmethod
    def getRangeAddressesAsString(self) -> str:
        """
        creates a string with addresses of all contained cell ranges.
        
        The range addresses are separated with semicolons. For instance the string could have the form \"Sheet1.A1:C3;Sheet2.D5:F8\".
        """
        ...

__all__ = ['XSheetCellRanges']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from .x_macro_expander import XMacroExpander as XMacroExpander_c8360c47

class MacroExpander(XComponent_98dc0ab5, XMacroExpander_c8360c47):
    """
    Service Class

    This meta service supports the XMacroExpander interface for expanding arbitrary macro expressions, i.e.
    
    substitute macro names. The purpose of this service is to separate the use of macrofied strings, e.g. urls from the use of services.
    
    **since**
    
        OOo 1.1.2
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API MacroExpander <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1util_1_1MacroExpander.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.MacroExpander'
    __ooo_type_name__: str = 'service'


__all__ = ['MacroExpander']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
from ..lang.x_localizable import XLocalizable as XLocalizable_aee00b64
from ..util.x_localized_aliases import XLocalizedAliases as XLocalizedAliases_ef7c0d77

class DatabaseAccessContext(XEnumerationAccess_4bac0ffc, XNameAccess_e2ab0cf6, XLocalizable_aee00b64, XLocalizedAliases_ef7c0d77):
    """
    Service Class

    is the context for data access beans.
    
    It allows to register aliases for database access beans. It is possible to have different aliases for different locales.
    
    A DatabaseContext stores an alias for the URL of a database access component for a given locale. It is also allowed to work with a default locale. This is useful in connection with Enumeration or NameAccess to the context. In common use, the default language is set during the initialization of the component.
    
    The service also provides a default handling for locales, where an alias isn't set. The first time an alias is registered for a programmatic name, the alias becomes the default for all other known locales.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API DatabaseAccessContext <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DatabaseAccessContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DatabaseAccessContext'
    __ooo_type_name__: str = 'service'


__all__ = ['DatabaseAccessContext']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.component
from __future__ import annotations
from abc import abstractproperty
from ..data_aware_control_model import DataAwareControlModel as DataAwareControlModel_27110ef8
from .text_field import TextField as TextField_db00e46

class DatabaseTextField(DataAwareControlModel_27110ef8, TextField_db00e46):
    """
    Service Class

    This service specifies a text field which is data-aware, and can be bound to a database field.

    See Also:
        `API DatabaseTextField <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseTextField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.component'
    __ooo_full_ns__: str = 'com.sun.star.form.component.DatabaseTextField'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ConvertEmptyToNull(self) -> bool:
        """
        determines if an empty text should be treated as a NULL value.
        
        When the user enters text into a text field, and after this, the control content is to be committed into the database field the control is bound to, a decision must be made how to deal with empty strings.This is controlled by this property.
        
        If the property is set to TRUE, and an empty text is to be committed, this is converted into NULL, else it is written as empty string.
        """
        ...


__all__ = ['DatabaseTextField']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.i18n.am_pm_value import AmPmValue as AmPmValue
with suppress(ImportError):
    from ...dyn.i18n.am_pm_value import AmPmValueEnum as AmPmValueEnum
with suppress(ImportError):
    from ...dyn.i18n.boundary import Boundary as Boundary
with suppress(ImportError):
    from ...dyn.i18n.break_iterator import BreakIterator as BreakIterator
with suppress(ImportError):
    from ...dyn.i18n.break_type import BreakType as BreakType
with suppress(ImportError):
    from ...dyn.i18n.break_type import BreakTypeEnum as BreakTypeEnum
with suppress(ImportError):
    from ...dyn.i18n.ctl_script_type import CTLScriptType as CTLScriptType
with suppress(ImportError):
    from ...dyn.i18n.ctl_script_type import CTLScriptTypeEnum as CTLScriptTypeEnum
with suppress(ImportError):
    from ...dyn.i18n.calendar import Calendar as Calendar
with suppress(ImportError):
    from ...dyn.i18n.calendar2 import Calendar2 as Calendar2
with suppress(ImportError):
    from ...dyn.i18n.calendar_display_code import CalendarDisplayCode as CalendarDisplayCode
with suppress(ImportError):
    from ...dyn.i18n.calendar_display_code import CalendarDisplayCodeEnum as CalendarDisplayCodeEnum
with suppress(ImportError):
    from ...dyn.i18n.calendar_display_index import CalendarDisplayIndex as CalendarDisplayIndex
with suppress(ImportError):
    from ...dyn.i18n.calendar_display_index import CalendarDisplayIndexEnum as CalendarDisplayIndexEnum
with suppress(ImportError):
    from ...dyn.i18n.calendar_field_index import CalendarFieldIndex as CalendarFieldIndex
with suppress(ImportError):
    from ...dyn.i18n.calendar_field_index import CalendarFieldIndexEnum as CalendarFieldIndexEnum
with suppress(ImportError):
    from ...dyn.i18n.calendar_item import CalendarItem as CalendarItem
with suppress(ImportError):
    from ...dyn.i18n.calendar_item2 import CalendarItem2 as CalendarItem2
with suppress(ImportError):
    from ...dyn.i18n.chapter_collator import ChapterCollator as ChapterCollator
with suppress(ImportError):
    from ...dyn.i18n.char_type import CharType as CharType
with suppress(ImportError):
    from ...dyn.i18n.char_type import CharTypeEnum as CharTypeEnum
with suppress(ImportError):
    from ...dyn.i18n.character_classification import CharacterClassification as CharacterClassification
with suppress(ImportError):
    from ...dyn.i18n.character_iterator_mode import CharacterIteratorMode as CharacterIteratorMode
with suppress(ImportError):
    from ...dyn.i18n.character_iterator_mode import CharacterIteratorModeEnum as CharacterIteratorModeEnum
with suppress(ImportError):
    from ...dyn.i18n.collator import Collator as Collator
with suppress(ImportError):
    from ...dyn.i18n.collator_options import CollatorOptions as CollatorOptions
with suppress(ImportError):
    from ...dyn.i18n.collator_options import CollatorOptionsEnum as CollatorOptionsEnum
with suppress(ImportError):
    from ...dyn.i18n.currency import Currency as Currency
with suppress(ImportError):
    from ...dyn.i18n.currency2 import Currency2 as Currency2
with suppress(ImportError):
    from ...dyn.i18n.direction_property import DirectionProperty as DirectionProperty
with suppress(ImportError):
    from ...dyn.i18n.forbidden_characters import ForbiddenCharacters as ForbiddenCharacters
with suppress(ImportError):
    from ...dyn.i18n.format_element import FormatElement as FormatElement
with suppress(ImportError):
    from ...dyn.i18n.implementation import Implementation as Implementation
with suppress(ImportError):
    from ...dyn.i18n.index_entry_supplier import IndexEntrySupplier as IndexEntrySupplier
with suppress(ImportError):
    from ...dyn.i18n.input_sequence_check_mode import InputSequenceCheckMode as InputSequenceCheckMode
with suppress(ImportError):
    from ...dyn.i18n.input_sequence_check_mode import InputSequenceCheckModeEnum as InputSequenceCheckModeEnum
with suppress(ImportError):
    from ...dyn.i18n.input_sequence_checker import InputSequenceChecker as InputSequenceChecker
with suppress(ImportError):
    from ...dyn.i18n.k_character_type import KCharacterType as KCharacterType
with suppress(ImportError):
    from ...dyn.i18n.k_character_type import KCharacterTypeEnum as KCharacterTypeEnum
with suppress(ImportError):
    from ...dyn.i18n.k_number_format_type import KNumberFormatType as KNumberFormatType
with suppress(ImportError):
    from ...dyn.i18n.k_number_format_type import KNumberFormatTypeEnum as KNumberFormatTypeEnum
with suppress(ImportError):
    from ...dyn.i18n.k_number_format_usage import KNumberFormatUsage as KNumberFormatUsage
with suppress(ImportError):
    from ...dyn.i18n.k_number_format_usage import KNumberFormatUsageEnum as KNumberFormatUsageEnum
with suppress(ImportError):
    from ...dyn.i18n.k_parse_tokens import KParseTokens as KParseTokens
with suppress(ImportError):
    from ...dyn.i18n.k_parse_tokens import KParseTokensEnum as KParseTokensEnum
with suppress(ImportError):
    from ...dyn.i18n.k_parse_type import KParseType as KParseType
with suppress(ImportError):
    from ...dyn.i18n.k_parse_type import KParseTypeEnum as KParseTypeEnum
with suppress(ImportError):
    from ...dyn.i18n.language_country_info import LanguageCountryInfo as LanguageCountryInfo
with suppress(ImportError):
    from ...dyn.i18n.line_break_hyphenation_options import LineBreakHyphenationOptions as LineBreakHyphenationOptions
with suppress(ImportError):
    from ...dyn.i18n.line_break_results import LineBreakResults as LineBreakResults
with suppress(ImportError):
    from ...dyn.i18n.line_break_user_options import LineBreakUserOptions as LineBreakUserOptions
with suppress(ImportError):
    from ...dyn.i18n.locale_calendar import LocaleCalendar as LocaleCalendar
with suppress(ImportError):
    from ...dyn.i18n.locale_calendar2 import LocaleCalendar2 as LocaleCalendar2
with suppress(ImportError):
    from ...dyn.i18n.locale_data import LocaleData as LocaleData
with suppress(ImportError):
    from ...dyn.i18n.locale_data2 import LocaleData2 as LocaleData2
with suppress(ImportError):
    from ...dyn.i18n.locale_data_item import LocaleDataItem as LocaleDataItem
with suppress(ImportError):
    from ...dyn.i18n.locale_data_item2 import LocaleDataItem2 as LocaleDataItem2
with suppress(ImportError):
    from ...dyn.i18n.locale_item import LocaleItem as LocaleItem
with suppress(ImportError):
    from ...dyn.i18n.locale_item import LocaleItemEnum as LocaleItemEnum
with suppress(ImportError):
    from ...dyn.i18n.months import Months as Months
with suppress(ImportError):
    from ...dyn.i18n.months import MonthsEnum as MonthsEnum
with suppress(ImportError):
    from ...dyn.i18n.multiple_chars_output_exception import MultipleCharsOutputException as MultipleCharsOutputException
with suppress(ImportError):
    from ...dyn.i18n.native_number_mode import NativeNumberMode as NativeNumberMode
with suppress(ImportError):
    from ...dyn.i18n.native_number_mode import NativeNumberModeEnum as NativeNumberModeEnum
with suppress(ImportError):
    from ...dyn.i18n.native_number_supplier import NativeNumberSupplier as NativeNumberSupplier
with suppress(ImportError):
    from ...dyn.i18n.native_number_supplier2 import NativeNumberSupplier2 as NativeNumberSupplier2
with suppress(ImportError):
    from ...dyn.i18n.native_number_xml_attributes import NativeNumberXmlAttributes as NativeNumberXmlAttributes
with suppress(ImportError):
    from ...dyn.i18n.native_number_xml_attributes2 import NativeNumberXmlAttributes2 as NativeNumberXmlAttributes2
with suppress(ImportError):
    from ...dyn.i18n.number_format_code import NumberFormatCode as NumberFormatCode
with suppress(ImportError):
    from ...dyn.i18n.number_format_index import NumberFormatIndex as NumberFormatIndex
with suppress(ImportError):
    from ...dyn.i18n.number_format_index import NumberFormatIndexEnum as NumberFormatIndexEnum
with suppress(ImportError):
    from ...dyn.i18n.number_format_mapper import NumberFormatMapper as NumberFormatMapper
with suppress(ImportError):
    from ...dyn.i18n.ordinal_suffix import OrdinalSuffix as OrdinalSuffix
with suppress(ImportError):
    from ...dyn.i18n.parse_result import ParseResult as ParseResult
with suppress(ImportError):
    from ...dyn.i18n.script_direction import ScriptDirection as ScriptDirection
with suppress(ImportError):
    from ...dyn.i18n.script_direction import ScriptDirectionEnum as ScriptDirectionEnum
with suppress(ImportError):
    from ...dyn.i18n.script_type import ScriptType as ScriptType
with suppress(ImportError):
    from ...dyn.i18n.script_type import ScriptTypeEnum as ScriptTypeEnum
with suppress(ImportError):
    from ...dyn.i18n.text_conversion import TextConversion as TextConversion
with suppress(ImportError):
    from ...dyn.i18n.text_conversion_option import TextConversionOption as TextConversionOption
with suppress(ImportError):
    from ...dyn.i18n.text_conversion_option import TextConversionOptionEnum as TextConversionOptionEnum
with suppress(ImportError):
    from ...dyn.i18n.text_conversion_result import TextConversionResult as TextConversionResult
with suppress(ImportError):
    from ...dyn.i18n.text_conversion_type import TextConversionType as TextConversionType
with suppress(ImportError):
    from ...dyn.i18n.text_conversion_type import TextConversionTypeEnum as TextConversionTypeEnum
with suppress(ImportError):
    from ...dyn.i18n.transliteration import Transliteration as Transliteration
with suppress(ImportError):
    from ...dyn.i18n.transliteration_modules import TransliterationModules as TransliterationModules
with suppress(ImportError):
    from ...dyn.i18n.transliteration_modules_extra import TransliterationModulesExtra as TransliterationModulesExtra
with suppress(ImportError):
    from ...dyn.i18n.transliteration_modules_extra import TransliterationModulesExtraEnum as TransliterationModulesExtraEnum
with suppress(ImportError):
    from ...dyn.i18n.transliteration_modules_new import TransliterationModulesNew as TransliterationModulesNew
with suppress(ImportError):
    from ...dyn.i18n.transliteration_type import TransliterationType as TransliterationType
with suppress(ImportError):
    from ...dyn.i18n.transliteration_type import TransliterationTypeEnum as TransliterationTypeEnum
with suppress(ImportError):
    from ...dyn.i18n.unicode_script import UnicodeScript as UnicodeScript
with suppress(ImportError):
    from ...dyn.i18n.unicode_type import UnicodeType as UnicodeType
with suppress(ImportError):
    from ...dyn.i18n.unicode_type import UnicodeTypeEnum as UnicodeTypeEnum
with suppress(ImportError):
    from ...dyn.i18n.weekdays import Weekdays as Weekdays
with suppress(ImportError):
    from ...dyn.i18n.weekdays import WeekdaysEnum as WeekdaysEnum
with suppress(ImportError):
    from ...dyn.i18n.word_type import WordType as WordType
with suppress(ImportError):
    from ...dyn.i18n.word_type import WordTypeEnum as WordTypeEnum
with suppress(ImportError):
    from ...dyn.i18n.x_break_iterator import XBreakIterator as XBreakIterator
with suppress(ImportError):
    from ...dyn.i18n.x_calendar import XCalendar as XCalendar
with suppress(ImportError):
    from ...dyn.i18n.x_calendar3 import XCalendar3 as XCalendar3
with suppress(ImportError):
    from ...dyn.i18n.x_calendar4 import XCalendar4 as XCalendar4
with suppress(ImportError):
    from ...dyn.i18n.x_character_classification import XCharacterClassification as XCharacterClassification
with suppress(ImportError):
    from ...dyn.i18n.x_collator import XCollator as XCollator
with suppress(ImportError):
    from ...dyn.i18n.x_extended_calendar import XExtendedCalendar as XExtendedCalendar
with suppress(ImportError):
    from ...dyn.i18n.x_extended_index_entry_supplier import XExtendedIndexEntrySupplier as XExtendedIndexEntrySupplier
with suppress(ImportError):
    from ...dyn.i18n.x_extended_input_sequence_checker import XExtendedInputSequenceChecker as XExtendedInputSequenceChecker
with suppress(ImportError):
    from ...dyn.i18n.x_extended_text_conversion import XExtendedTextConversion as XExtendedTextConversion
with suppress(ImportError):
    from ...dyn.i18n.x_extended_transliteration import XExtendedTransliteration as XExtendedTransliteration
with suppress(ImportError):
    from ...dyn.i18n.x_forbidden_characters import XForbiddenCharacters as XForbiddenCharacters
with suppress(ImportError):
    from ...dyn.i18n.x_index_entry_supplier import XIndexEntrySupplier as XIndexEntrySupplier
with suppress(ImportError):
    from ...dyn.i18n.x_input_sequence_checker import XInputSequenceChecker as XInputSequenceChecker
with suppress(ImportError):
    from ...dyn.i18n.x_locale_data import XLocaleData as XLocaleData
with suppress(ImportError):
    from ...dyn.i18n.x_locale_data2 import XLocaleData2 as XLocaleData2
with suppress(ImportError):
    from ...dyn.i18n.x_locale_data3 import XLocaleData3 as XLocaleData3
with suppress(ImportError):
    from ...dyn.i18n.x_locale_data4 import XLocaleData4 as XLocaleData4
with suppress(ImportError):
    from ...dyn.i18n.x_locale_data5 import XLocaleData5 as XLocaleData5
with suppress(ImportError):
    from ...dyn.i18n.x_native_number_supplier import XNativeNumberSupplier as XNativeNumberSupplier
with suppress(ImportError):
    from ...dyn.i18n.x_native_number_supplier2 import XNativeNumberSupplier2 as XNativeNumberSupplier2
with suppress(ImportError):
    from ...dyn.i18n.x_number_format_code import XNumberFormatCode as XNumberFormatCode
with suppress(ImportError):
    from ...dyn.i18n.x_ordinal_suffix import XOrdinalSuffix as XOrdinalSuffix
with suppress(ImportError):
    from ...dyn.i18n.x_script_type_detector import XScriptTypeDetector as XScriptTypeDetector
with suppress(ImportError):
    from ...dyn.i18n.x_text_conversion import XTextConversion as XTextConversion
with suppress(ImportError):
    from ...dyn.i18n.x_transliteration import XTransliteration as XTransliteration
with suppress(ImportError):
    from ...dyn.i18n.reserved_words import reservedWords as reservedWords
with suppress(ImportError):
    from ...dyn.i18n.reserved_words import reservedWordsEnum as reservedWordsEnum



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XUntitledNumbers(XInterface_8f010a43):
    """
    knows all currently used and all free numbers for using with untitled but counted objects.

    See Also:
        `API XUntitledNumbers <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XUntitledNumbers.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XUntitledNumbers'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XUntitledNumbers'

    @abstractmethod
    def getUntitledPrefix(self) -> str:
        """
        returns the localized string value to be used for untitled objects in combination with the leased number.
        
        Note: Such string already contains leading spaces/tabs etc. ! The only thing which an outside code has todo then ... adding a leased number to the string.
        """
        ...
    @abstractmethod
    def leaseNumber(self, xComponent: XInterface_8f010a43) -> int:
        """
        callee has to lease a number before he can use it within in its own title.
        
        Such number must be freed after using e.g. while the object was closed or gets another title (e.g. by saving a document to a real location on disc).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def releaseNumber(self, nNumber: int) -> None:
        """
        has to be used to mark those numbers as \"free for using\".
        
        If the registered component does not use such leased number any longer it has to be released so it can be used for new components.
        
        Note: calling this method with an unknown (but normally valid number) has to be ignored. No exceptions - no errors.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def releaseNumberForComponent(self, xComponent: XInterface_8f010a43) -> None:
        """
        does the same then releaseNumber () but it searches the corresponding number for the specified component and deregister it.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XUntitledNumbers']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbc


class ColumnSearch(object):
    """
    Const Class

    indicates in which way a column can be used in the WHERE search.

    See Also:
        `API ColumnSearch <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdbc_1_1ColumnSearch.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbc'
    __ooo_full_ns__: str = 'com.sun.star.sdbc.ColumnSearch'
    __ooo_type_name__: str = 'const'

    NONE = 0
    """
    A possible value for column SEARCHABLE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc.XDatabaseMetaData.getTypeInfo().
    
    Indicates that WHERE search clauses are not supported for this type.
    """
    CHAR = 1
    """
    A possible value for column SEARCHABLE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc.XDatabaseMetaData.getTypeInfo().
    
    Indicates that the only WHERE search clause that can be based on this type is WHERE...LIKE.
    """
    BASIC = 2
    """
    A possible value for column SEARCHABLE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc\">XDatabaseMetaData.getTypeInfo().
    
    Indicates that one can base all WHERE search clauses except WHERE...LIKE on this data type.
    """
    FULL = 3
    """
    A possible value for column SEARCHABLE in the com.sun.star.sdbc.XResultSet object returned by the method com.sun.star.sdbc\">XDatabaseMetaData.getTypeInfo().
    
    Indicates that all WHERE search clauses can be based on this type.
    """

__all__ = ['ColumnSearch']
